ExSaml.BoostrapProvidersLoader (ex_saml v1.0.1)

Copy Markdown View Source

GenServer that loads SAML providers after the application and database are ready. Uses retry logic to handle cases where the database isn't available yet.

Summary

Functions

Returns a specification to start this module under a supervisor.

Callback implementation for GenServer.init/1.

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

init(opts)

Callback implementation for GenServer.init/1.

loaded?()

reload()

start_link(opts)