ExSaml.ErrorMessages (ex_saml v1.0.2)

Copy Markdown View Source

Error messages

Provide explanation for an error from its error code

Example

iex(2)> ExSaml.ErrorMessages.get(:bad_audience)
"Make sure that the entity_id in configuration is correct"

iex(3)> ExSaml.ErrorMessages.get(:cert_no_accepted)
"Make sure the Identity Provider metadata XML file you are
using in the config setting is correct and corresponds to the
IdP you are attempting to talk to, you get this error if the
certificate used by the IdP to sign the SAML responses has
changed and you don't have the updated IdP metadata XML file"