ExSaml.RelayStateCache (ex_saml v1.0.2)

Copy Markdown View Source

TTL-based relay state cache with anti-replay protection.

Stores relay state data during the SAML authentication flow. Uses the cache module configured via config :ex_saml, cache: MyApp.Cache.

The take/1 function atomically retrieves and deletes the relay state, preventing replay attacks.

Summary

Functions

Deletes the relay state for the given key.

Retrieves the relay state data for the given key.

Stores relay state data with a TTL.

Atomically retrieves and deletes the relay state (anti-replay).

Returns the remaining TTL for the given relay state key.

Functions

delete(key)

Deletes the relay state for the given key.

get(key)

Retrieves the relay state data for the given key.

put(key, assertion, list)

Stores relay state data with a TTL.

take(key)

Atomically retrieves and deletes the relay state (anti-replay).

ttl(key)

Returns the remaining TTL for the given relay state key.