ExSaml.State (ex_saml v1.0.2)

Copy Markdown View Source

Interface for SAML assertion storage.

Delegates to the configured store provider (ExSaml.State.ETS, ExSaml.State.Session, or ExSaml.State.Cache). Configure the store in your config.exs:

config :ex_saml, ExSaml.State,
  store: ExSaml.State.ETS

To implement a custom store, see ExSaml.State.Store.

Summary

Functions

Removes the SAML assertion for the given key from the store.

Generates a cryptographically random URL-safe identifier.

Retrieves the SAML assertion for the given key from the store.

Initializes the state store with default options.

Initializes the state store with the given options.

Stores a SAML assertion with the given key.

Functions

delete_assertion(conn, assertion_key)

Removes the SAML assertion for the given key from the store.

gen_id()

Generates a cryptographically random URL-safe identifier.

get_assertion(conn, assertion_key)

Retrieves the SAML assertion for the given key from the store.

init(store_provider)

Initializes the state store with default options.

init(store_provider, opts)

Initializes the state store with the given options.

put_assertion(conn, assertion_key, assertion)

Stores a SAML assertion with the given key.