Stores SAML assertion in Plug session.
This provider uses Plug session to save the authenticated SAML assertions from IdP. The session key name in the configuration is optional.
Options
-
:key- Session key name used when saving the assertion (optional)Value is either a binary or an atom
Configuration Example
config :ex_saml, ExSaml.State,
store: ExSaml.State.Session,
opts: [key: :my_assertion]