GenServer that loads SAML providers after the application and database are ready. Uses retry logic to handle cases where the database isn't available yet.
Summary
Functions
Returns a specification to start this module under a supervisor.
Callback implementation for GenServer.init/1.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Callback implementation for GenServer.init/1.