XML Canonicalization (C14N) for xmerl data structures.
Implements the W3C Exclusive XML Canonicalization specification: http://www.w3.org/TR/xml-c14n
Operates on xmerl records (xmlElement, xmlAttribute, etc.).
Summary
Functions
Puts an XML document or element into canonical form, as a string.
Puts an XML document or element into canonical form, as a string.
Puts an XML document or element into canonical form, as a string.
Returns the canonical namespace-URI-prefix-resolved version of an XML name.
Make XML content safe (non-quoted context).
Make XML content safe. If quotes is true, also escapes double quotes.
Types
@type xml_thing() :: {:xmlDocument, content :: term()} | {:xmlElement, name :: term(), expanded_name :: term(), nsinfo :: term(), namespace :: term(), parents :: term(), pos :: term(), attributes :: term(), content :: term(), language :: term(), xmlbase :: term(), elementdef :: term()} | {:xmlAttribute, name :: term(), expanded_name :: term(), nsinfo :: term(), namespace :: term(), parents :: term(), pos :: term(), language :: term(), value :: term(), normalized :: term()} | {:xmlPI, name :: term(), parents :: term(), pos :: term(), value :: term()} | {:xmlText, parents :: term(), pos :: term(), language :: term(), value :: term(), type :: term()} | {:xmlComment, parents :: term(), pos :: term(), language :: term(), value :: term()}
Functions
Puts an XML document or element into canonical form, as a string.
Puts an XML document or element into canonical form, as a string.
If comments is true, preserves comments in the output.
Puts an XML document or element into canonical form, as a string.
If comments is true, preserves comments in the output. Any namespace
prefixes listed in inclusive_ns will be left as they are and not
modified during canonicalization.
@spec canon_name( {:xmlElement, name :: term(), expanded_name :: term(), nsinfo :: term(), namespace :: term(), parents :: term(), pos :: term(), attributes :: term(), content :: term(), language :: term(), xmlbase :: term(), elementdef :: term()} | {:xmlAttribute, name :: term(), expanded_name :: term(), nsinfo :: term(), namespace :: term(), parents :: term(), pos :: term(), language :: term(), value :: term(), normalized :: term()} ) :: String.t()
Returns the canonical namespace-URI-prefix-resolved version of an XML name.
Make XML content safe (non-quoted context).
Make XML content safe. If quotes is true, also escapes double quotes.