Interface for SAML assertion storage.
Delegates to the configured store provider (ExSaml.State.ETS, ExSaml.State.Session,
or ExSaml.State.Cache). Configure the store in your config.exs:
config :ex_saml, ExSaml.State,
store: ExSaml.State.ETSTo implement a custom store, see ExSaml.State.Store.
Summary
Functions
Removes the SAML assertion for the given key from the store.
Generates a cryptographically random URL-safe identifier.
Retrieves the SAML assertion for the given key from the store.
Initializes the state store with default options.
Initializes the state store with the given options.
Stores a SAML assertion with the given key.
Functions
Removes the SAML assertion for the given key from the store.
Generates a cryptographically random URL-safe identifier.
Retrieves the SAML assertion for the given key from the store.
Initializes the state store with default options.
Initializes the state store with the given options.
Stores a SAML assertion with the given key.